@@ -29,27 +29,26 @@ from ..option import Option, RegistryOption
 
 
 class cmd_git_import(Command):
-    """Import all branches from a git repository.
-
-    """
+    """Import all branches from a git repository."""
 
     takes_args = ["src_location", "dest_location?"]
 
     takes_options = [
-        Option('colocated', help='Create colocated branches.'),
-        RegistryOption('dest-format',
-                       help='Specify a format for this branch. '
-                       'See "help formats" for a full list.',
-                       lazy_registry=('breezy.controldir', 'format_registry'),
-                       converter=lambda name: controldir.format_registry.make_controldir(
-                            name),
-                       value_switches=True,
-                       title="Branch format",
-                       ),
-        ]
+        Option("colocated", help="Create colocated branches."),
+        RegistryOption(
+            "dest-format",
+            help="Specify a format for this branch. "
+            'See "help formats" for a full list.',
+            lazy_registry=("breezy.controldir", "format_registry"),
+            converter=lambda name: controldir.format_registry.make_controldir(name),
+            value_switches=True,
+            title="Branch format",
+        ),
+    ]
 
     def _get_colocated_branch(self, target_controldir, name):
         from ..errors import NotBranchError
+
         try:
             return target_controldir.open_branch(name=name)
         except NotBranchError:
@@ -58,12 +57,14 @@ class cmd_git_import(Command):
     def _get_nested_branch(self, dest_transport, dest_format, name):
         from ..controldir import ControlDir
         from ..errors import NotBranchError
+
         head_transport = dest_transport.clone(name)
         try:
             head_controldir = ControlDir.open_from_transport(head_transport)
         except NotBranchError:
             head_controldir = dest_format.initialize_on_transport_ex(
-                head_transport, create_prefix=True)[1]
+                head_transport, create_prefix=True
+            )[1]
         try:
             return head_controldir.open_branch()
         except NotBranchError:
@@ -74,8 +75,7 @@ class cmd_git_import(Command):
 
         from .. import controldir, trace, ui, urlutils
         from ..controldir import ControlDir
-        from ..errors import (BzrError, CommandError, NoRepositoryPresent,
-                              NotBranchError)
+        from ..errors import BzrError, CommandError, NoRepositoryPresent, NotBranchError
         from ..i18n import gettext
         from ..repository import InterRepository, Repository
         from ..transport import get_transport
@@ -84,7 +84,7 @@ class cmd_git_import(Command):
         from .repository import GitRepository
 
         if dest_format is None:
-            dest_format = controldir.format_registry.make_controldir('default')
+            dest_format = controldir.format_registry.make_controldir("default")
 
         if dest_location is None:
             dest_location = os.path.basename(src_location.rstrip("/\\"))
@@ -93,21 +93,20 @@ class cmd_git_import(Command):
 
         source_repo = Repository.open(src_location)
         if not isinstance(source_repo, GitRepository):
-            raise CommandError(
-                gettext("%r is not a git repository") % src_location)
+            raise CommandError(gettext("%r is not a git repository") % src_location)
         try:
             target_controldir = ControlDir.open_from_transport(dest_transport)
         except NotBranchError:
             target_controldir = dest_format.initialize_on_transport_ex(
-                dest_transport, shared_repo=True)[1]
+                dest_transport, shared_repo=True
+            )[1]
         try:
             target_repo = target_controldir.find_repository()
         except NoRepositoryPresent:
             target_repo = target_controldir.create_repository(shared=True)
 
         if not target_repo.supports_rich_root():
-            raise CommandError(
-                gettext("Target repository doesn't support rich roots"))
+            raise CommandError(gettext("Target repository doesn't support rich roots"))
 
         interrepo = InterRepository.get(source_repo, target_repo)
         mapping = source_repo.get_mapping()
@@ -120,29 +119,35 @@ class cmd_git_import(Command):
                     # Not a branch, ignore
                     continue
                 pb.update(gettext("creating branches"), i, len(result.refs))
-                if (getattr(target_controldir._format, "colocated_branches",
-                            False) and colocated):
+                if (
+                    getattr(target_controldir._format, "colocated_branches", False)
+                    and colocated
+                ):
                     if name == "HEAD":
                         branch_name = None
                     head_branch = self._get_colocated_branch(
-                        target_controldir, branch_name)
+                        target_controldir, branch_name
+                    )
                 else:
                     head_branch = self._get_nested_branch(
-                        dest_transport, dest_format, branch_name)
+                        dest_transport, dest_format, branch_name
+                    )
                 revid = mapping.revision_id_foreign_to_bzr(sha)
-                source_branch = LocalGitBranch(
-                    source_repo.controldir, source_repo, sha)
+                source_branch = LocalGitBranch(source_repo.controldir, source_repo, sha)
                 if head_branch.last_revision() != revid:
                     head_branch.generate_revision_history(revid)
                 source_branch.tags.merge_to(head_branch.tags)
                 if not head_branch.get_parent():
                     url = urlutils.join_segment_parameters(
-                        source_branch.base,
-                        {"branch": urlutils.escape(branch_name)})
+                        source_branch.base, {"branch": urlutils.escape(branch_name)}
+                    )
                     head_branch.set_parent(url)
-        trace.note(gettext(
-            "Use 'bzr checkout' to create a working tree in "
-            "the newly created branches."))
+        trace.note(
+            gettext(
+                "Use 'bzr checkout' to create a working tree in "
+                "the newly created branches."
+            )
+        )
 
 
 class cmd_git_object(Command):
@@ -156,11 +161,11 @@ class cmd_git_object(Command):
 
     aliases = ["git-objects", "git-cat"]
     takes_args = ["sha1?"]
-    takes_options = [Option('directory',
-                            short_name='d',
-                            help='Location of repository.', type=str),
-                     Option('pretty', help='Pretty-print objects.')]
-    encoding_type = 'exact'
+    takes_options = [
+        Option("directory", short_name="d", help="Location of repository.", type=str),
+        Option("pretty", help="Pretty-print objects."),
+    ]
+    encoding_type = "exact"
 
     @display_command
     def run(self, sha1=None, directory=".", pretty=False):
@@ -168,16 +173,16 @@ class cmd_git_object(Command):
         from ..errors import CommandError
         from ..i18n import gettext
         from .object_store import get_object_store
+
         controldir, _ = ControlDir.open_containing(directory)
         repo = controldir.find_repository()
         object_store = get_object_store(repo)
         with object_store.lock_read():
             if sha1 is not None:
                 try:
-                    obj = object_store[sha1.encode('ascii')]
+                    obj = object_store[sha1.encode("ascii")]
                 except KeyError:
-                    raise CommandError(
-                        gettext("Object not found: %s") % sha1)
+                    raise CommandError(gettext("Object not found: %s") % sha1)
                 if pretty:
                     text = obj.as_pretty_string()
                 else:
@@ -185,13 +190,11 @@ class cmd_git_object(Command):
                 self.outf.write(text)
             else:
                 for sha1 in object_store:
-                    self.outf.write("%s\n" % sha1.decode('ascii'))
+                    self.outf.write("%s\n" % sha1.decode("ascii"))
 
 
 class cmd_git_refs(Command):
-    """Output all of the virtual refs for a repository.
-
-    """
+    """Output all of the virtual refs for a repository."""
 
     hidden = True
 
@@ -202,14 +205,14 @@ class cmd_git_refs(Command):
         from ..controldir import ControlDir
         from .object_store import get_object_store
         from .refs import get_refs_container
+
         controldir, _ = ControlDir.open_containing(location)
         repo = controldir.find_repository()
         object_store = get_object_store(repo)
         with object_store.lock_read():
             refs = get_refs_container(controldir, object_store)
             for k, v in sorted(refs.as_dict().items()):
-                self.outf.write("%s -> %s\n" %
-                                (k.decode('utf-8'), v.decode('utf-8')))
+                self.outf.write("%s -> %s\n" % (k.decode("utf-8"), v.decode("utf-8")))
 
 
 class cmd_git_apply(Command):
@@ -219,10 +222,9 @@ class cmd_git_apply(Command):
     """
 
     takes_options = [
-        Option('signoff', short_name='s', help='Add a Signed-off-by line.'),
-        Option('force',
-               help='Apply patches even if tree has uncommitted changes.')
-        ]
+        Option("signoff", short_name="s", help="Add a Signed-off-by line."),
+        Option("force", help="Apply patches even if tree has uncommitted changes."),
+    ]
     takes_args = ["patches*"]
 
     def _apply_patch(self, wt, f, signoff):
@@ -235,19 +237,21 @@ class cmd_git_apply(Command):
         from dulwich.patch import git_am_patch_split
 
         from breezy.patch import patch_tree
+
         (c, diff, version) = git_am_patch_split(f)
         # FIXME: Cope with git-specific bits in patch
         # FIXME: Add new files to working tree
         patch_tree(wt, [diff], strip=1, out=self.outf)
-        message = c.message.decode('utf-8')
+        message = c.message.decode("utf-8")
         if signoff:
             signed_off_by = wt.branch.get_config().username()
             message += "Signed-off-by: {}\n".format(signed_off_by)
-        wt.commit(authors=[c.author.decode('utf-8')], message=message)
+        wt.commit(authors=[c.author.decode("utf-8")], message=message)
 
     def run(self, patches_list=None, signoff=False, force=False):
         from ..errors import UncommittedChanges
         from ..workingtree import WorkingTree
+
         if patches_list is None:
             patches_list = []
 
@@ -263,23 +267,26 @@ class cmd_git_apply(Command):
 class cmd_git_push_pristine_tar_deltas(Command):
     """Push pristine tar deltas to a git repository."""
 
-    takes_options = [Option('directory',
-                            short_name='d',
-                            help='Location of repository.', type=str)]
-    takes_args = ['target', 'package']
+    takes_options = [
+        Option("directory", short_name="d", help="Location of repository.", type=str)
+    ]
+    takes_args = ["target", "package"]
 
-    def run(self, target, package, directory='.'):
+    def run(self, target, package, directory="."):
         from ..branch import Branch
         from ..errors import CommandError, NoSuchRevision
         from ..repository import Repository
         from ..trace import warning
         from .mapping import encode_git_path
         from .object_store import get_object_store
-        from .pristine_tar import (revision_pristine_tar_data,
-                                   store_git_pristine_tar_data)
+        from .pristine_tar import (
+            revision_pristine_tar_data,
+            store_git_pristine_tar_data,
+        )
+
         source = Branch.open_containing(directory)[0]
         target_bzr = Repository.open(target)
-        target = getattr(target_bzr, '_git', None)
+        target = getattr(target_bzr, "_git", None)
         if target is None:
             raise CommandError("Target not a git repository")
         git_store = get_object_store(source.repository)
@@ -295,18 +302,19 @@ class cmd_git_push_pristine_tar_deltas(Command):
                 except KeyError:
                     continue
                 gitid = git_store._lookup_revision_sha1(revid)
-                if (not (name.startswith('upstream/') or
-                         name.startswith('upstream-'))):
+                if not (name.startswith("upstream/") or name.startswith("upstream-")):
                     warning(
-                        "Unexpected pristine tar revision tagged %s. "
-                        "Ignoring.", name)
+                        "Unexpected pristine tar revision tagged %s. " "Ignoring.", name
+                    )
                     continue
-                upstream_version = name[len("upstream/"):]
-                filename = '{}_{}.orig.tar.{}'.format(
-                    package, upstream_version, kind)
+                upstream_version = name[len("upstream/") :]
+                filename = "{}_{}.orig.tar.{}".format(package, upstream_version, kind)
                 if gitid not in target:
                     warning(
                         "base git id %s for %s missing in target repository",
-                        gitid, filename)
-                store_git_pristine_tar_data(target, encode_git_path(filename),
-                                            delta, gitid)
+                        gitid,
+                        filename,
+                    )
+                store_git_pristine_tar_data(
+                    target, encode_git_path(filename), delta, gitid
+                )
