@@ -15,7 +15,6 @@
 
 """Import processor that supports all Bazaar repository formats."""
 
-
 import time
 
 import configobj
@@ -28,8 +27,14 @@ from .... import debug, delta, errors, osutils, progress
 from .... import revision as _mod_revision
 from ....bzr.knitpack_repo import KnitPackRepository
 from ....trace import mutter, note, warning
-from .. import (branch_updater, cache_manager, helpers, idmapfile, marks_file,
-                revision_store)
+from .. import (
+    branch_updater,
+    cache_manager,
+    helpers,
+    idmapfile,
+    marks_file,
+    revision_store,
+)
 
 # How many commits before automatically reporting progress
 _DEFAULT_AUTO_PROGRESS = 1000
@@ -95,19 +100,20 @@ class GenericProcessor(processor.ImportProcessor):
     """
 
     known_params = [
-        'info',
-        'trees',
-        'count',
-        'checkpoint',
-        'autopack',
-        'inv-cache',
-        'mode',
-        'import-marks',
-        'export-marks',
-        ]
+        "info",
+        "trees",
+        "count",
+        "checkpoint",
+        "autopack",
+        "inv-cache",
+        "mode",
+        "import-marks",
+        "export-marks",
+    ]
 
-    def __init__(self, bzrdir, params=None, verbose=False, outf=None,
-                 prune_empty_dirs=True):
+    def __init__(
+        self, bzrdir, params=None, verbose=False, outf=None, prune_empty_dirs=True
+    ):
         processor.ImportProcessor.__init__(self, params, verbose)
         self.prune_empty_dirs = prune_empty_dirs
         self.controldir = bzrdir
@@ -125,16 +131,15 @@ class GenericProcessor(processor.ImportProcessor):
         self._start_time = time.time()
         self._load_info_and_params()
         if self.total_commits:
-            self.note("Starting import of %d commits ..." %
-                      (self.total_commits,))
+            self.note("Starting import of %d commits ..." % (self.total_commits,))
         else:
             self.note("Starting import ...")
-        self.cache_mgr = cache_manager.CacheManager(self.info, self.verbose,
-                                                    self.inventory_cache_size)
+        self.cache_mgr = cache_manager.CacheManager(
+            self.info, self.verbose, self.inventory_cache_size
+        )
 
         if self.params.get("import-marks") is not None:
-            mark_info = marks_file.import_marks(
-                self.params.get("import-marks"))
+            mark_info = marks_file.import_marks(self.params.get("import-marks"))
             if mark_info is not None:
                 self.cache_mgr.marks = mark_info
             self.skip_total = False
@@ -143,8 +148,10 @@ class GenericProcessor(processor.ImportProcessor):
             self.first_incremental_commit = False
             self.skip_total = self._init_id_map()
             if self.skip_total:
-                self.note("Found %d commits already loaded - "
-                          "skipping over these ...", self.skip_total)
+                self.note(
+                    "Found %d commits already loaded - " "skipping over these ...",
+                    self.skip_total,
+                )
         self._revision_count = 0
 
         # mapping of tag name to revision_id
@@ -156,13 +163,12 @@ class GenericProcessor(processor.ImportProcessor):
         # Disable autopacking if the repo format supports it.
         # THIS IS A HACK - there is no sanctioned way of doing this yet.
         if isinstance(self.repo, KnitPackRepository):
-            self._original_max_pack_count = \
-                self.repo._pack_collection._max_pack_count
+            self._original_max_pack_count = self.repo._pack_collection._max_pack_count
 
             def _max_pack_count_for_import(total_revisions):
                 return total_revisions + 1
-            self.repo._pack_collection._max_pack_count = \
-                _max_pack_count_for_import
+
+            self.repo._pack_collection._max_pack_count = _max_pack_count_for_import
         else:
             self._original_max_pack_count = None
 
@@ -171,6 +177,7 @@ class GenericProcessor(processor.ImportProcessor):
         # is available to do a better job of saving space.
         try:
             from .... import groupcompress
+
             groupcompress._FAST = True
         except ImportError:
             pass
@@ -188,7 +195,7 @@ class GenericProcessor(processor.ImportProcessor):
         self.id_map_path = repo_transport.local_abspath("fastimport-id-map")
 
         # Load the info file, if any
-        info_path = self.params.get('info')
+        info_path = self.params.get("info")
         if info_path is not None:
             self.info = configobj.ConfigObj(info_path)
         else:
@@ -204,16 +211,16 @@ class GenericProcessor(processor.ImportProcessor):
             self.progress_every = self.progress_every / 10
 
         # Decide how often (# of commits) to automatically checkpoint
-        self.checkpoint_every = int(self.params.get('checkpoint',
-                                                    _DEFAULT_AUTO_CHECKPOINT))
+        self.checkpoint_every = int(
+            self.params.get("checkpoint", _DEFAULT_AUTO_CHECKPOINT)
+        )
 
         # Decide how often (# of checkpoints) to automatically pack
         self.checkpoint_count = 0
-        self.autopack_every = int(self.params.get('autopack',
-                                                  _DEFAULT_AUTO_PACK))
+        self.autopack_every = int(self.params.get("autopack", _DEFAULT_AUTO_PACK))
 
         # Decide how big to make the inventory cache
-        cache_size = int(self.params.get('inv-cache', -1))
+        cache_size = int(self.params.get("inv-cache", -1))
         if cache_size == -1:
             if self.supports_chk:
                 cache_size = _DEFAULT_CHK_INV_CACHE_SIZE
@@ -227,15 +234,14 @@ class GenericProcessor(processor.ImportProcessor):
         # at which we need to terminate separately to the total used
         # for progress tracking.
         try:
-            self.max_commits = int(self.params['count'])
+            self.max_commits = int(self.params["count"])
             if self.max_commits < 0:
                 self.max_commits = None
         except KeyError:
             self.max_commits = None
         if self.info is not None:
-            self.total_commits = int(self.info['Command counts']['commit'])
-            if (self.max_commits is not None
-                    and self.total_commits > self.max_commits):
+            self.total_commits = int(self.info["Command counts"]["commit"])
+            if self.max_commits is not None and self.total_commits > self.max_commits:
                 self.total_commits = self.max_commits
         else:
             self.total_commits = self.max_commits
@@ -284,8 +290,9 @@ class GenericProcessor(processor.ImportProcessor):
         self._save_id_map()
 
         if self.params.get("export-marks") is not None:
-            marks_file.export_marks(self.params.get("export-marks"),
-                                    self.cache_mgr.marks)
+            marks_file.export_marks(
+                self.params.get("export-marks"), self.cache_mgr.marks
+            )
 
         if self.cache_mgr.reftracker.last_ref is None:
             """Nothing to refresh"""
@@ -293,18 +300,23 @@ class GenericProcessor(processor.ImportProcessor):
 
         # Update the branches
         self.note("Updating branch information ...")
-        updater = branch_updater.BranchUpdater(self.repo, self.branch,
-                                               self.cache_mgr, invert_dictset(
-                                                   self.cache_mgr.reftracker.heads),
-                                               self.cache_mgr.reftracker.last_ref, self.tags)
+        updater = branch_updater.BranchUpdater(
+            self.repo,
+            self.branch,
+            self.cache_mgr,
+            invert_dictset(self.cache_mgr.reftracker.heads),
+            self.cache_mgr.reftracker.last_ref,
+            self.tags,
+        )
         branches_updated, branches_lost = updater.update()
         self._branch_count = len(branches_updated)
 
         # Tell the user about branches that were not created
         if branches_lost:
             if not self.repo.is_shared():
-                self.warning("Cannot import multiple branches into "
-                             "a standalone branch")
+                self.warning(
+                    "Cannot import multiple branches into " "a standalone branch"
+                )
             self.warning("Not creating branches for these head revisions:")
             for lost_info in branches_lost:
                 head_revision = lost_info[1]
@@ -318,7 +330,7 @@ class GenericProcessor(processor.ImportProcessor):
             self.note("no branches to update")
             self.note("no working trees to update")
             remind_about_update = False
-        elif self.params.get('trees', False):
+        elif self.params.get("trees", False):
             trees = self._get_working_trees(branches_updated)
             if trees:
                 self._update_working_trees(trees)
@@ -348,8 +360,10 @@ class GenericProcessor(processor.ImportProcessor):
         self.dump_stats()
         if remind_about_update:
             # This message is explicitly not timestamped.
-            note("To refresh the working tree for other branches, "
-                 "use 'bzr update' inside that branch.")
+            note(
+                "To refresh the working tree for other branches, "
+                "use 'bzr update' inside that branch."
+            )
 
     def _update_working_trees(self, trees):
         if self.verbose:
@@ -365,6 +379,7 @@ class GenericProcessor(processor.ImportProcessor):
         # Before packing, free whatever memory we can and ensure
         # that groupcompress is configured to optimise disk space
         import gc
+
         if final:
             try:
                 from .... import groupcompress
@@ -382,8 +397,8 @@ class GenericProcessor(processor.ImportProcessor):
         self.note("Removing obsolete packs ...")
         # TODO: Use a public API for this once one exists
         repo_transport = self.repo._pack_collection.transport
-        obsolete_pack_transport = repo_transport.clone('obsolete_packs')
-        for name in obsolete_pack_transport.list_dir('.'):
+        obsolete_pack_transport = repo_transport.clone("obsolete_packs")
+        for name in obsolete_pack_transport.list_dir("."):
             obsolete_pack_transport.delete(name)
 
         # If we're not done, free whatever memory we can
@@ -412,11 +427,16 @@ class GenericProcessor(processor.ImportProcessor):
         rc = self._revision_count - self.skip_total
         bc = self._branch_count
         wtc = self._tree_count
-        self.note("Imported %d %s, updating %d %s and %d %s in %s",
-                  rc, helpers.single_plural(rc, "revision", "revisions"),
-                  bc, helpers.single_plural(bc, "branch", "branches"),
-                  wtc, helpers.single_plural(wtc, "tree", "trees"),
-                  time_required)
+        self.note(
+            "Imported %d %s, updating %d %s and %d %s in %s",
+            rc,
+            helpers.single_plural(rc, "revision", "revisions"),
+            bc,
+            helpers.single_plural(bc, "branch", "branches"),
+            wtc,
+            helpers.single_plural(wtc, "tree", "trees"),
+            time_required,
+        )
 
     def _init_id_map(self):
         """Load the id-map and check it matches the repository.
@@ -426,9 +446,8 @@ class GenericProcessor(processor.ImportProcessor):
         # Currently, we just check the size. In the future, we might
         # decide to be more paranoid and check that the revision-ids
         # are identical as well.
-        self.cache_mgr.marks, known = idmapfile.load_id_map(
-            self.id_map_path)
-        if self.cache_mgr.add_mark(b'0', _mod_revision.NULL_REVISION):
+        self.cache_mgr.marks, known = idmapfile.load_id_map(self.id_map_path)
+        if self.cache_mgr.add_mark(b"0", _mod_revision.NULL_REVISION):
             known += 1
 
         existing_count = len(self.repo.all_revision_ids())
@@ -464,7 +483,7 @@ class GenericProcessor(processor.ImportProcessor):
 
     def commit_handler(self, cmd):
         """Process a CommitCommand."""
-        mark = cmd.id.lstrip(b':')
+        mark = cmd.id.lstrip(b":")
         if self.skip_total and self._revision_count < self.skip_total:
             self.cache_mgr.reftracker.track_heads(cmd)
             # Check that we really do know about this commit-id
@@ -472,8 +491,8 @@ class GenericProcessor(processor.ImportProcessor):
                 raise plugin_errors.BadRestart(mark)
             self.cache_mgr._blobs = {}
             self._revision_count += 1
-            if cmd.ref.startswith(b'refs/tags/'):
-                tag_name = cmd.ref[len(b'refs/tags/'):]
+            if cmd.ref.startswith(b"refs/tags/"):
+                tag_name = cmd.ref[len(b"refs/tags/") :]
                 self._set_tag(tag_name, cmd.id)
             return
         if self.first_incremental_commit:
@@ -481,9 +500,13 @@ class GenericProcessor(processor.ImportProcessor):
             parents = self.cache_mgr.reftracker.track_heads(cmd)
 
         # 'Commit' the revision and report progress
-        handler = self.commit_handler_factory(cmd, self.cache_mgr,
-                                              self.rev_store, verbose=self.verbose,
-                                              prune_empty_dirs=self.prune_empty_dirs)
+        handler = self.commit_handler_factory(
+            cmd,
+            self.cache_mgr,
+            self.rev_store,
+            verbose=self.verbose,
+            prune_empty_dirs=self.prune_empty_dirs,
+        )
         try:
             handler.process()
         except:
@@ -491,23 +514,23 @@ class GenericProcessor(processor.ImportProcessor):
             raise
         self.cache_mgr.add_mark(mark, handler.revision_id)
         self._revision_count += 1
-        self.report_progress("(%s)" % cmd.id.lstrip(b':'))
+        self.report_progress("(%s)" % cmd.id.lstrip(b":"))
 
-        if cmd.ref.startswith(b'refs/tags/'):
-            tag_name = cmd.ref[len(b'refs/tags/'):]
+        if cmd.ref.startswith(b"refs/tags/"):
+            tag_name = cmd.ref[len(b"refs/tags/") :]
             self._set_tag(tag_name, cmd.id)
 
         # Check if we should finish up or automatically checkpoint
-        if (self.max_commits is not None
-                and self._revision_count >= self.max_commits):
+        if self.max_commits is not None and self._revision_count >= self.max_commits:
             self.note("Stopping after reaching requested count of commits")
             self.finished = True
         elif self._revision_count % self.checkpoint_every == 0:
-            self.note("%d commits - automatic checkpoint triggered",
-                      self._revision_count)
+            self.note(
+                "%d commits - automatic checkpoint triggered", self._revision_count
+            )
             self.checkpoint_handler(None)
 
-    def report_progress(self, details=''):
+    def report_progress(self, details=""):
         if self._revision_count % self.progress_every == 0:
             if self.total_commits is not None:
                 counts = "%d/%d" % (self._revision_count, self.total_commits)
@@ -520,8 +543,7 @@ class GenericProcessor(processor.ImportProcessor):
                 rate_str = "at %.0f/minute " % rate
             else:
                 rate_str = "at %.1f/minute " % rate
-            self.note("%s commits processed %s%s" %
-                      (counts, rate_str, details))
+            self.note("%s commits processed %s%s" % (counts, rate_str, details))
 
     def progress_handler(self, cmd):
         """Process a ProgressCommand."""
@@ -532,13 +554,12 @@ class GenericProcessor(processor.ImportProcessor):
 
     def reset_handler(self, cmd):
         """Process a ResetCommand."""
-        if cmd.ref.startswith(b'refs/tags/'):
-            tag_name = cmd.ref[len(b'refs/tags/'):]
+        if cmd.ref.startswith(b"refs/tags/"):
+            tag_name = cmd.ref[len(b"refs/tags/") :]
             if cmd.from_ is not None:
                 self._set_tag(tag_name, cmd.from_)
             elif self.verbose:
-                self.warning("ignoring reset refs/tags/%s - no from clause"
-                             % tag_name)
+                self.warning("ignoring reset refs/tags/%s - no from clause" % tag_name)
             return
 
         if cmd.from_ is not None:
@@ -553,7 +574,7 @@ class GenericProcessor(processor.ImportProcessor):
 
     def _set_tag(self, name, from_):
         """Define a tag given a name and import 'from' reference."""
-        bzr_tag_name = name.decode('utf-8', 'replace')
+        bzr_tag_name = name.decode("utf-8", "replace")
         bzr_rev_id = self.cache_mgr.lookup_committish(from_)
         self.tags[bzr_tag_name] = bzr_rev_id
 
